﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace XamGridAddUpdateDelete
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            xamGrid1.ItemsSource = Data.GetData(10, 10, 100);
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            (xamGrid1.ItemsSource as ObservableCollection<Data>).Add(new Data());
        }

        private void button2_Click(object sender, RoutedEventArgs e)
        {
            xamGrid1.EnterEditMode(xamGrid1.SelectionSettings.SelectedCells.FirstOrDefault());
        }

        private void button3_Click(object sender, RoutedEventArgs e)
        {
            if (xamGrid1.SelectionSettings.SelectedRows.Count == 0)
            {
                MessageBox.Show("You must select a Row first !!!", "Warning", MessageBoxButton.OK, MessageBoxImage.Warning);
            }
            else
                xamGrid1.SelectionSettings.SelectedRows.FirstOrDefault().Delete();
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private int value;
        private string label;
        private DateTime date;


        public DateTime Date
        {
            get { return date; }
            set
            {
                date = value;
                PropChanged("Date");
            }
        }


        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public double Avarage
        {
            get
            {
                return (Open + Close + High + Low) / 4;
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Date = DateTime.Now.AddDays(i),
                    Label = "Item " + i,
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(rangeStart, rangeEnd),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                    Value = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
